@@ -35,7 +35,7 @@ namespace lms::db
 {
     namespace
     {
-        static constexpr Version LMS_DATABASE_VERSION{ 64 };
+        static constexpr Version LMS_DATABASE_VERSION{ 67 };
     }
 
     VersionInfo::VersionInfo()
@@ -714,6 +714,53 @@ SELECT
         session.getDboSession()->execute("DROP INDEX IF EXISTS listen_user_backend_date_time");
     }
 
+    void migrateFromV64(Session& session)
+    {
+        session.getDboSession()->execute(R"(CREATE TABLE IF NOT EXISTS "label" (
+  "id" integer primary key autoincrement,
+  "version" integer not null,
+  "name" text not null
+))");
+
+        session.getDboSession()->execute(R"(CREATE TABLE IF NOT EXISTS "release_label" (
+  "label_id" bigint,
+  "release_id" bigint,
+  primary key ("label_id", "release_id"),
+  constraint "fk_release_label_key1" foreign key ("label_id") references "label" ("id") on delete cascade deferrable initially deferred,
+  constraint "fk_release_label_key2" foreign key ("release_id") references "release" ("id") on delete cascade deferrable initially deferred
+))");
+        session.getDboSession()->execute(R"(CREATE INDEX "release_label_label" on "release_label" ("label_id"))");
+        session.getDboSession()->execute(R"(CREATE INDEX "release_label_release" on "release_label" ("release_id"))");
+
+        // Just increment the scan version of the settings to make the next scheduled scan rescan everything
+        session.getDboSession()->execute("UPDATE scan_settings SET scan_version = scan_version + 1");
+    }
+
+    void migrateFromV65(Session& session)
+    {
+        session.getDboSession()->execute("ALTER TABLE release ADD is_compilation BOOLEAN NOT NULL DEFAULT(false)");
+
+        // Just increment the scan version of the settings to make the next scheduled scan rescan everything
+        session.getDboSession()->execute("UPDATE scan_settings SET scan_version = scan_version + 1");
+    }
+
+    void migrateFromV66(Session& session)
+    {
+        // New way of handling UI settings
+        session.getDboSession()->execute(R"(CREATE TABLE IF NOT EXISTS "ui_state" (
+  "id" integer primary key autoincrement,
+  "version" integer not null,
+  "item" text not null,
+  "value" text not null,
+  "user_id" bigint,
+  constraint "fk_ui_state_user" foreign key ("user_id") references "user" ("id") on delete cascade deferrable initially deferred
+))");
+
+        session.getDboSession()->execute("ALTER TABLE user DROP COLUMN repeat_all");
+        session.getDboSession()->execute("ALTER TABLE user DROP COLUMN radio");
+        session.getDboSession()->execute("ALTER TABLE user DROP COLUMN cur_playing_track_pos");
+    }
+
     bool doDbMigration(Session& session)
     {
         static const std::string outdatedMsg{ "Outdated database, please rebuild it (delete the .db file and restart)" };
@@ -754,6 +801,9 @@ SELECT
             { 61, migrateFromV61 },
             { 62, migrateFromV62 },
             { 63, migrateFromV63 },
+            { 64, migrateFromV64 },
+            { 65, migrateFromV65 },
+            { 66, migrateFromV66 },
         };
 
         bool migrationPerformed{};
