@@ -207,34 +207,34 @@ namespace lms::ui
 
     db::User::pointer LmsApplication::getUser()
     {
-        if (!_authenticatedUser)
+        if (!_user)
             return {};
 
-        return db::User::find(getDbSession(), _authenticatedUser->userId);
+        return db::User::find(getDbSession(), _user->userId);
     }
 
-    db::UserId LmsApplication::getUserId()
+    db::UserId LmsApplication::getUserId() const
     {
-        return _authenticatedUser->userId;
+        assert(_user);
+        return _user->userId;
     }
 
     bool LmsApplication::isUserAuthStrong() const
     {
-        return _authenticatedUser->strongAuth;
+        assert(_user);
+        return _user->strongAuth;
     }
 
-    db::UserType LmsApplication::getUserType()
+    db::UserType LmsApplication::getUserType() const
     {
-        auto transaction{ getDbSession().createReadTransaction() };
-
-        return getUser()->getType();
+        assert(_user);
+        return _user->userType;
     }
 
-    std::string LmsApplication::getUserLoginName()
+    std::string_view LmsApplication::getUserLoginName() const
     {
-        auto transaction{ getDbSession().createReadTransaction() };
-
-        return getUser()->getLoginName();
+        assert(_user);
+        return _user->userLoginName;
     }
 
     LmsApplication::LmsApplication(const Wt::WEnvironment& env,
@@ -244,11 +244,10 @@ namespace lms::ui
         : Wt::WApplication{ env }
         , _db{ db }
         , _appManager{ appManager }
-        , _authenticatedUser{ userId ? std::make_optional<UserAuthInfo>(UserAuthInfo{ *userId, false }) : std::nullopt }
     {
         try
         {
-            init();
+            init(userId);
         }
         catch (LmsApplicationException& e)
         {
@@ -264,7 +263,7 @@ namespace lms::ui
 
     LmsApplication::~LmsApplication() = default;
 
-    void LmsApplication::init()
+    void LmsApplication::init(std::optional<db::UserId> userId)
     {
         LMS_SCOPED_TRACE_OVERVIEW("UI", "ApplicationInit");
 
@@ -279,8 +278,8 @@ namespace lms::ui
         // Handle Media Scanner events and other session events
         enableUpdates(true);
 
-        if (_authenticatedUser)
-            onUserLoggedIn();
+        if (userId)
+            onUserLoggedIn(*userId, false /* strongAuth */);
         else if (core::Service<auth::IPasswordService>::exists())
             processPasswordAuth();
     }
@@ -292,8 +291,7 @@ namespace lms::ui
             if (userId)
             {
                 LMS_LOG(UI, DEBUG, "User authenticated using Auth token!");
-                _authenticatedUser = { *userId, false };
-                onUserLoggedIn();
+                onUserLoggedIn(*userId, false /* strongAuth */);
                 return;
             }
         }
@@ -315,15 +313,14 @@ namespace lms::ui
         {
             Auth* auth{ root()->addNew<Auth>() };
             auth->userLoggedIn.connect(this, [this](db::UserId userId) {
-                _authenticatedUser = { userId, true };
-                onUserLoggedIn();
+                onUserLoggedIn(userId, true /* strongAuth */);
             });
         }
     }
 
     void LmsApplication::finalize()
     {
-        if (_authenticatedUser)
+        if (_user)
             _appManager.unregisterApplication(*this);
 
         preQuit().emit();
@@ -359,10 +356,12 @@ namespace lms::ui
         goHomeAndQuit();
     }
 
-    void LmsApplication::onUserLoggedIn()
+    void LmsApplication::onUserLoggedIn(db::UserId userId, bool strongAuth)
     {
         root()->clear();
 
+        setUserInfo(userId, strongAuth);
+
         LMS_LOG(UI, INFO, "User '" << getUserLoginName() << "' logged in from '" << environment().clientAddress() << "', user agent = " << environment().userAgent());
 
         _appManager.registerApplication(*this);
@@ -380,6 +379,23 @@ namespace lms::ui
         createHome();
     }
 
+    void LmsApplication::setUserInfo(db::UserId userId, bool strongAuth)
+    {
+        auto transaction{ getDbSession().createReadTransaction() };
+
+        const db::User::pointer user{ db::User::find(getDbSession(), userId) };
+        if (!user)
+            throw core::LmsException{ "Internal error" }; // Do not put details here at it may appear on the user rendered html
+
+        assert(!_user);
+        _user = UserAuthInfo{
+            .userId = userId,
+            .userType = user->getType(),
+            .userLoginName = user->getLoginName(),
+            .strongAuth = strongAuth
+        };
+    }
+
     void LmsApplication::createHome()
     {
         LMS_SCOPED_TRACE_OVERVIEW("UI", "ApplicationCreateHome");
@@ -420,7 +436,7 @@ namespace lms::ui
         navbar->bindNew<Wt::WAnchor>("tracklists", Wt::WLink{ Wt::LinkType::InternalPath, "/tracklists" }, Wt::WString::tr("Lms.Explore.tracklists"));
 
         Filters* filters{ navbar->bindNew<Filters>("filters") };
-        navbar->bindString("username", getUserLoginName(), Wt::TextFormat::Plain);
+        navbar->bindString("username", std::string{ getUserLoginName() }, Wt::TextFormat::Plain);
         navbar->bindNew<Wt::WAnchor>("settings", Wt::WLink{ Wt::LinkType::InternalPath, "/settings" }, Wt::WString::tr("Lms.Settings.menu-settings"));
 
         {
